@@ -67,6 +67,7 @@ struct _MMModemClass {
 };
 
 GType mm_modem_get_type (void);
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (MMModem, g_object_unref)
 
 const gchar *mm_modem_get_path (MMModem *self);
 gchar       *mm_modem_dup_path (MMModem *self);
@@ -99,6 +100,11 @@ gchar             *mm_modem_dup_model                (MMModem *self);
 const gchar       *mm_modem_get_revision             (MMModem *self);
 gchar             *mm_modem_dup_revision             (MMModem *self);
 
+const gchar       *mm_modem_get_carrier_configuration          (MMModem *self);
+gchar             *mm_modem_dup_carrier_configuration          (MMModem *self);
+const gchar       *mm_modem_get_carrier_configuration_revision (MMModem *self);
+gchar             *mm_modem_dup_carrier_configuration_revision (MMModem *self);
+
 const gchar       *mm_modem_get_hardware_revision    (MMModem *self);
 gchar             *mm_modem_dup_hardware_revision    (MMModem *self);
 
